@@ -20,9 +20,7 @@
 #include <dbus/dbus-glib-lowlevel.h>
 
 #include "cpufreq-selector.h"
-#include "cpufreq-selector-factory.h"
 #include "cpufreq-selector-service.h"
-
 #include "cpufreq-selector-service-glue.h"
 
 #define MAX_CPUS 255
@@ -230,7 +228,10 @@ cpufreq_selector_service_register (CPUFreqSelectorService *service,
 		return FALSE;
 	}
 
-	service->authority = polkit_authority_get ();
+	service->authority = polkit_authority_get_sync (NULL, error);
+
+	if (!service->authority)
+	  return FALSE;
 
 	service->system_bus = connection;
 
@@ -252,7 +253,7 @@ get_selector_for_cpu (CPUFreqSelectorService *service,
 		      guint                   cpu)
 {
 	if (!service->selectors[cpu]) {
-		service->selectors[cpu] = cpufreq_selector_factory_create_selector (cpu);
+		service->selectors[cpu] = cpufreq_selector_new (cpu);
 		if (!service->selectors[cpu])
 			return NULL;
 		
